@@ -5,10 +5,12 @@ from .util import datetimeToHPTime, hptimeToDatetime, utcnowWithTz, encodeAuthTo
 from .socketdali import SocketDataLink
 from .websocketdali import WebSocketDataLink
 from .miniseed import MiniseedHeader, MiniseedRecord, unpackMiniseedHeader, unpackMiniseedRecord, unpackBlockette
+from .dali2jsonl import Dali2Jsonl
 
 __all__ = [ DataLink,
             DaliResponse,
             DaliPacket,
+            Dali2Jsonl,
             datetimeToHPTime,
             hptimeToDatetime,
             JsonEncoder,
